@@ -9,7 +9,7 @@ export PYTHON_VERSION=system
 LANG=en_US.UTF-8
 export LANG
 DEBIAN_FRONTEND=noninteractive apt-get install -y --no-install-recommends \
-    sudo locales tzdata software-properties-common python3-dev python3-pip python3-setuptools git curl \
+    sudo locales tzdata software-properties-common python3-dev python3-venv python3-pip python3-setuptools git curl \
     apt-transport-https ca-certificates gnupg software-properties-common wget
 #install PHP 8.1
 DEBIAN_FRONTEND=noninteractive add-apt-repository ppa:ondrej/php -y
@@ -41,8 +41,8 @@ ci/ubuntu/setup.sh
 ci/ubuntu/build.sh
 
 # Validate openapi document
-pip install check-jsonschema
-wget https://raw.githubusercontent.com/OAI/OpenAPI-Specification/main/schemas/v3.0/schema.yaml -O openapi_schema.yaml
+pip install check-jsonschema --break-system-packages
+wget https://raw.githubusercontent.com/OAI/OpenAPI-Specification/refs/heads/main/_archive_/schemas/v3.0/schema.yaml -O openapi_schema.yaml
 echo "Run check-jsonschema --schemafile openapi_schema.yaml msautotest/api/expected/ogcapi_api.json"
 check-jsonschema --schemafile openapi_schema.yaml msautotest/api/expected/ogcapi_api.json
 
