@@ -83,7 +83,7 @@ static enum MS_RING_DIRECTION mvtGetRingDirection(lineObj *ring) {
   if (ring->numpoints < 4)
     return MS_DIRECTION_INVALID_RING;
 
-  /* step throught the edges */
+  /* step through the edges */
   for (i = 0; i < ring->numpoints - 1; i++) {
     sum += ring->point[i].x * ring->point[i + 1].y -
            ring->point[i + 1].x * ring->point[i].y;
@@ -186,7 +186,7 @@ static int mvtTransformShape(shapeObj *shape, rectObj *extent, int layer_type,
   msFree(outers);
 
   return (shape->numlines == 0) ? MS_FAILURE
-                                : MS_SUCCESS; /* sucess if at least one line */
+                                : MS_SUCCESS; /* success if at least one line */
 }
 
 static int mvtClipShape(shapeObj *shape, int layer_type, int buffer,
@@ -662,6 +662,7 @@ int msPopulateRendererVTableMVT(rendererVTableObj *renderer) {
 }
 #else
 int msPopulateRendererVTableMVT(rendererVTableObj *renderer) {
+  (void)renderer;
   msSetError(MS_MISCERR,
              "Vector Tile Driver requested but support is not compiled in",
              "msPopulateRendererVTableMVT()");
@@ -669,6 +670,8 @@ int msPopulateRendererVTableMVT(rendererVTableObj *renderer) {
 }
 
 int msMVTWriteTile(mapObj *map, int sendheaders) {
+  (void)map;
+  (void)sendheaders;
   msSetError(MS_MISCERR, "Vector Tile support is not available.",
              "msMVTWriteTile()");
   return MS_FAILURE;
