@@ -30,6 +30,7 @@
 #include "mapows.h"
 #include "mapgml.h"
 #include "maptime.h"
+#include "mapogcfilter.h"
 
 #include "cpl_conv.h"
 
@@ -273,13 +274,20 @@ static bool getBbox(mapObj *map, layerObj *layer, cgiRequestObj *request,
   int status;
 
   const char *bboxParam = getRequestParameter(request, "bbox");
-  if (!bboxParam ||
-      strlen(bboxParam) == 0) { // missing or empty - assign map->extent (no
-                                // projection necessary)
-    bbox->minx = map->extent.minx;
-    bbox->miny = map->extent.miny;
-    bbox->maxx = map->extent.maxx;
-    bbox->maxy = map->extent.maxy;
+  if (!bboxParam || strlen(bboxParam) == 0) { // missing or empty extent
+    rectObj rect;
+    if (FLTLayerSetInvalidRectIfSupported(layer, &rect, "AO")) {
+      bbox->minx = rect.minx;
+      bbox->miny = rect.miny;
+      bbox->maxx = rect.maxx;
+      bbox->maxy = rect.maxy;
+    } else {
+      // assign map->extent (no projection necessary)
+      bbox->minx = map->extent.minx;
+      bbox->miny = map->extent.miny;
+      bbox->maxx = map->extent.maxx;
+      bbox->maxy = map->extent.maxy;
+    }
   } else {
     const auto tokens = msStringSplit(bboxParam, ',');
     if (tokens.size() != 4) {
@@ -617,7 +625,7 @@ static json getFeatureGeometry(shapeObj *shape, int precision,
           json polygon = json::array();
           for (int i = 0; i < shape->numlines; i++) {
             if (i == k ||
-                outerList[i] ==
+                innerList[i] ==
                     MS_TRUE) { // add outer ring (k) and any inner rings
               json part = json::array();
               for (int j = 0; j < shape->line[i].numpoints; j++) {
@@ -1877,9 +1885,8 @@ static int processApiRequest(mapObj *map, cgiRequestObj *request,
       {"content",
        {{"application/json",
          {{"schema",
-           {{"$ref", "https://raw.githubusercontent.com/opengeospatial/"
-                     "ogcapi-processes/master/core/openapi/schemas/"
-                     "exception.yaml"}}}}}}}};
+           {{"$ref", "https://schemas.opengis.net/ogcapi/common/part1/1.0/"
+                     "openapi/schemas/exception.yaml"}}}}}}}};
 
   json parameters;
   parameters["f"] = {
